# PWBus - DynamicService Class
#:
#:  maintainer: fabio.szostak@perfweb.com.br | Mon Nov 18 09:30:57 -03 2019

import importlib
import os.path
import traceback

from pwbus.commons.logging import *

# DynamicService
#
#


class DynamicService():

    def __init__(self, service_id, payload, isDebugEnabled=False):
        try:
            service_name = service_id.split('.')
            module_name = f'pwbus_services.{service_name[0]}.{service_name[1]}'
            class_name = service_name[1].capitalize()
        except:
            log_debug(
                f'🟥 DynamicService - Invalid service_id [{service_id}] specify "module.class" (lowercase)')
            return

        try:
            if not os.path.isfile(module_name.replace('.', '/') + '.py'):
                log_debug(
                    f'🟥 DynamicService - module not found [{service_id}] specify "module.class" (lowercase)')
                return

            module = importlib.import_module(module_name)
            class_ = getattr(module, class_name)
            self.instance = class_(payload)

            if isDebugEnabled:
                log_debug(
                    f'DynamicService - Module [{module_name}] Class [{class_name}] instance created')

        except:
            log_debug(
                f'⚠️ DynamicService - WARNING!!! Class not found or with errors for service_id [{service_id}]')
            traceback.print_exc()
            raise

    # DynamicService.getInstance
    #
    def getInstance(self):
        return self.instance

    # DynamicService.isLoaded
    #
    def isLoaded(self):
        return True if self.instance else False



#!/usr/bin/env python3

### PWBus - Main
#:
#:  maintainer: fabio.szostak@perfweb.com.br | Tue Nov 19 11:17:54 -03 2019

__author__ = 'fszostak@gmail.com'

import sys
import getopt
import traceback

from pwbus.commons.logging import log_exit
from pwbus.engines.engine_manager import EngineManager


def main():
    argv = sys.argv[1:]

    channel = None
    engine = None
    command = None

    help_message = '\npwbus [-e <engine>] [-c <channel> start\n\n      -e <redis|socket>\n      --engine=<redis|socket>\n\n      -c <channel_id>\n      --channel=channel_id\n\n      start the server\n'

    try:
        opts, args = getopt.getopt(argv, "he:c:", ["start|channel=|engine="])
    except getopt.GetoptError:
        print(help_message)
        sys.exit(2)

    for opt, arg in opts:
        if opt == '-h':
            print(help_message)
            sys.exit()
        elif opt == 'start':
            command = arg
        elif opt in ("-e", "--engine"):
            engine = arg
        elif opt in ("-c", "--channel"):
            channel = arg

    for arg in args:
        if arg == "start":
            command = arg

    try:
        if command:
            engine_manager = EngineManager()
            engine_manager.action(command, engine, channel)
            sys.exit(0)

    except:
        sys.exit(1)

    print(help_message)


# __main__
#
if __name__ == "__main__":
    main()



### PWBus - Config Class 
#:  Load file: etc/pwbus.json
#:
#:  maintainer: fabio.szostak@perfweb.com.br | Sat Nov 16 16:36:36 -03 2019

from json import load

class Config():

  def __init__(self):
    with open('etc/engine.json') as json_file:
      self.config_data = load(json_file)

  ## Config.get
  #
  def get(self, name):
    if name in self.config_data:
      return self.config_data[name]
    return None
  